[PATCH] riscv: replace deprecated scall with ecall

Fangrui Song maskray at google.com
Sun Apr 23 15:32:10 PDT 2023


scall is a deprecated alias for ecall. ecall is used in several places,
so there is no assembler compatibility concern.

Signed-off-by: Fangrui Song <maskray at google.com>
---
 arch/riscv/kernel/entry.S             | 4 ++--
 arch/riscv/kernel/vdso/rt_sigreturn.S | 2 +-
 2 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/arch/riscv/kernel/vdso/rt_sigreturn.S b/arch/riscv/kernel/vdso/rt_sigreturn.S
index 0573705eac76..10438c7c626a 100644
--- a/arch/riscv/kernel/vdso/rt_sigreturn.S
+++ b/arch/riscv/kernel/vdso/rt_sigreturn.S
@@ -11,6 +11,6 @@ ENTRY(__vdso_rt_sigreturn)
 	.cfi_startproc
 	.cfi_signal_frame
 	li a7, __NR_rt_sigreturn
-	scall
+	ecall
 	.cfi_endproc
 ENDPROC(__vdso_rt_sigreturn)
diff --git a/arch/riscv/kernel/entry.S b/arch/riscv/kernel/entry.S
index 99d38fdf8b18..2f51935612d1 100644
--- a/arch/riscv/kernel/entry.S
+++ b/arch/riscv/kernel/entry.S
@@ -191,7 +191,7 @@ handle_syscall:
 	REG_S a0, PT_ORIG_A0(sp)
 	/*
 	 * Advance SEPC to avoid executing the original
 	 * scall instruction on sret
 	 */
 	addi s2, s2, 0x4
 	REG_S s2, PT_EPC(sp)
@@ -603,6 +603,6 @@ END(excp_vect_table)
 #ifndef CONFIG_MMU
 ENTRY(__user_rt_sigreturn)
 	li a7, __NR_rt_sigreturn
-	scall
+	ecall
 END(__user_rt_sigreturn)
 #endif
@@ -191,7 +191,7 @@ handle_syscall:
 	/*
 	 * Advance SEPC to avoid executing the original
-	 * scall instruction on sret
+	 * ecall instruction on sret
 	 */
 	addi s2, s2, 0x4
-- 
2.40.0.634.g4ca3ef3211-goog




More information about the linux-riscv mailing list